/*
   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "updatevideoconferencemessagejobtest.h"
#include "videoconference/updatevideoconferencemessagejob.h"
#include <QTest>

QTEST_GUILESS_MAIN(UpdateVideoConferenceMessageJobTest)

UpdateVideoConferenceMessageJobTest::UpdateVideoConferenceMessageJobTest(QObject *parent)
    : QObject{parent}
{
}

void UpdateVideoConferenceMessageJobTest::shouldHaveDefaultValues()
{
    UpdateVideoConferenceMessageJob job;
    QVERIFY(!job.rocketChatAccount());
    QVERIFY(!job.canStart());
    QVERIFY(!job.videoConferenceInfo().isValid());
}

#include "moc_updatevideoconferencemessagejobtest.cpp"
